just_manager library
Classes
-
JM<
T> - JM is a custom ChangeNotifier wrapper that allows getting, setting, and manually notifying listeners of a value.
- JMListener
- A widget that listens to multiple JM instances and rebuilds its child when any of them changes.
- JMListenerSingle
- A widget that listens to a single JM instance and rebuilds its child when the JM changes.
- JMScaffold
- A custom Scaffold that rebuilds its body whenever the specified JM listenables change.